import { AdRecord } from "../records/ad.record"
import { pool } from "../utils/db";

const defaultObj = {
    name: '[Test] Name',
    description: 'blah',
    url: 'https://megak.pl',
    price: 0,
    lat: 9,
    lon: 9,
}

afterAll(async () => {
    await pool.execute("DELETE FROM `ads` WHERE `name` LIKE '%[Test]%';")
    await pool.end();
})

test('AdRecord returns data from database for one entry.', async () => {
    const ad = await AdRecord.getOne('abc');

    expect(ad).toBeDefined();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('testowa');
})

test('AdRecord return null from database for unexisting entry', async () => {
    const ad = await AdRecord.getOne('---');

    expect(ad).toBeNull();
})

test('AdRecord.findAll returns array of entries', async () => {
    const ads = await AdRecord.findAll('');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll returns array of entries searching for "a"', async () => {
    const ads = await AdRecord.findAll('a');

    expect(ads).not.toEqual([]);
    expect(ads[0].id).toBeDefined();
})

test('AdRecord.findAll return empty array for unexisting entry', async () => {
    const ads = await AdRecord.findAll('--------------');

    expect(ads).toEqual([]);
})

test('AdRecord.findAll return smaller data of entries', async () => {
    const ads = await AdRecord.findAll('');

    expect((ads[0] as AdRecord).description).toBeUndefined();
    expect((ads[0] as AdRecord).price).toBeUndefined();
})

test('AdRecord.insert return uuid.', async () => {
    const ad = new AdRecord(defaultObj);

    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
})

test('AdRecord.insert inserts data to database.', async () => {
    const ad = new AdRecord(defaultObj);
    await ad.insert();

    const found = await AdRecord.getOne(ad.id);


    expect(found).toBeDefined();
    expect(found.id).toBe(ad.id);
})