"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccountRecord = void 0;
const error_1 = require("../utils/error");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class AccountRecord {
    constructor(obj) {
        if (!obj.login || obj.login.length > 50 || obj.login.length < 14) {
            throw new error_1.ValidationError('Login\'s length has to be between 14 and 50 characters.');
        }
        if (!obj.password || obj.password.length > 50) {
            throw new error_1.ValidationError('Password cant be empty and longer than 50 characters.');
        }
        this.id = obj.id;
        this.login = obj.login;
        this.password = obj.password;
        this.email = obj.email;
    }
    static checkLogin(login) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("Select * from `accounts` where `login` = :login", {
                login,
            });
            return results.length === 0 ? null : new AccountRecord(results[0]);
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            else {
                throw new Error('Cannot insert something that is already inserted.');
            }
            yield db_1.pool.execute('INSERT INTO `accounts` VALUES(:id, :login, :password, :email)', this);
        });
    }
}
exports.AccountRecord = AccountRecord;
//# sourceMappingURL=account.record.js.map