import { AccountEntity, NewAccountEntity } from "../types";
import { ValidationError } from "../utils/error";
import { v4 as uuid } from 'uuid';
import { pool } from '../utils/db';
import { FieldPacket } from "mysql2";

type AccountRecordResults = [AccountEntity[], FieldPacket[]];


export class AccountRecord implements AccountEntity {
    public id: string | undefined;
    public login: string;
    public password: string;
    public email: string;

    constructor(obj: NewAccountEntity) {
        if (!obj.login || obj.login.length > 50 || obj.login.length < 14) {
            throw new ValidationError('Login\'s length has to be between 14 and 50 characters.');
        }
        if (!obj.password || obj.password.length > 50) {
            throw new ValidationError('Password cant be empty and longer than 50 characters.');
        }

        this.id = obj.id;
        this.login = obj.login;
        this.password = obj.password;
        this.email = obj.email;
    }

    static async checkLogin(login: string): Promise<AccountRecord | null> {
        const [results] = await pool.execute("Select * from `accounts` where `login` = :login", {
            login,
        }) as AccountRecordResults;

        return results.length === 0 ? null : new AccountRecord(results[0]);
    }

    async insert() {
        if (!this.id) {
            this.id = uuid();
        } else {
            throw new Error('Cannot insert something that is already inserted.')
        }

        await pool.execute('INSERT INTO `accounts` VALUES(:id, :login, :password, :email)', this);
    }
}